import { defineUntypedSchema } from "untyped";
import definerSchema from "./DefinerModes.js";
const schema = defineUntypedSchema({
    directory: {
        $default: "__generated__",
        $resolve: value => (typeof value === "string" ? value : "__generated__"),
    },
    debug: {
        $default: false,
        $resolve: Boolean,
    },
    preCompile: {
        $default: false,
        $resolve: Boolean,
    },
    definerModes: definerSchema,
    debugFileName: {
        $default: "debug_{{ TIMESTAMP }}.json",
        $resolve: value => (typeof value === "string" ? value : "debug_{{ TIMESTAMP }}.json"),
    },
    domainFileName: {
        $default: "_custom_types.ts",
        $resolve: value => (typeof value === "string" ? value : "_custom_types.ts"),
    },
    domainName: {
        $default: "{{ TYPE_NAME | camel-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ TYPE_NAME | camel-case }}"),
    },
    enumName: {
        $default: "{{ TYPE_NAME | pascal-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ TYPE_NAME | pascal-case }}"),
    },
    enumFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/enums/{{ TYPE_NAME | pascal-case }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/enums/{{ TYPE_NAME | pascal-case }}.ts"),
    },
    columnName: {
        $default: "{{ COLUMN_NAME | camel-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ COLUMN_NAME | camel-case }}"),
    },
    tableTypeName: {
        $default: "{{ SCHEMA_NAME | pascal-case }}{{ TABLE_NAME | pascal-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ SCHEMA_NAME | pascal-case }}{{ TABLE_NAME | pascal-case }}"),
    },
    tableTypeFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
        $resolve: value => typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
    },
    tableInsertTypeName: {
        $default: "New{{ SCHEMA_NAME | pascal-case }}{{ TABLE_NAME | pascal-case }}",
        $resolve: value => (typeof value === "string" ? value : "New{{ SCHEMA_NAME | pascal-case }}{{ TABLE_NAME | pascal-case }}"),
    },
    tableInsertTypeFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
        $resolve: value => typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
    },
    tableName: {
        $default: "{{ SCHEMA_NAME | camel-case }}{{ TABLE_NAME | pascal-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ SCHEMA_NAME | camel-case }}{{ TABLE_NAME | pascal-case }}"),
    },
    tableFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
        $resolve: value => typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}/{{ TABLE_NAME | camel-case }}.ts",
    },
    schemaName: {
        $default: "{{ SCHEMA_NAME | camel-case }}",
        $resolve: value => (typeof value === "string" ? value : "{{ SCHEMA_NAME | camel-case }}"),
    },
    schemasFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/schemas.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/schemas.ts"),
    },
    schemaFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}/{{ SCHEMA_NAME | camel-case }}.ts"),
    },
    databaseFileName: {
        $default: "databases/{{ DATABASE_NAME | camel-case }}.ts",
        $resolve: value => (typeof value === "string" ? value : "databases/{{ DATABASE_NAME | camel-case }}.ts"),
    },
    definerTypeOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
    definerOverrides: {
        $default: {},
        $resolve: value => {
            if (typeof value === "object")
                return value;
            return {};
        },
    },
});
export default schema;
//# sourceMappingURL=FilesConfig.js.map